.. _examples-analysis:

Analysis
========

Examples about **numerical operations** on rasters, and **additional analysis features** such as **distance estimation** or **point extraction**.

Some examples rely on NumPy or pythonic operators on :class:`Rasters<geoutils.Raster>` (see :ref:`core-py-ops` and :ref:`core-array-funcs`).

Others also benefit from match-reference (see :ref:`core-match-ref`).
